<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'Intégrer TextWheel dans SPIP',
	'tw_slogan' => 'Gestion de la typographie SPIP avec TextWheel',
];
